@@ -46,7 +46,7 @@ struct Pg_dir_state => {
 };
 
 use constant {
-    VERSIONNUM       => "1.8.1",
+    VERSIONNUM       => "1.8.2",
     VERSIONINFO      => "[0] (pg-rex_operation_tools) [1]\n",
     CONFIG_PATH      => "/etc/",
     CONFIG_FILENAME  => "pg-rex_tools.conf",
@@ -570,13 +570,22 @@ sub read_config{
         && $config_value{'BACKUP_NODE_SSH_PASS_MODE'} ne "nopass" ){
        printlog("ERROR", COMMON_MS0034, "BACKUP_NODE_SSH_PASS_MODE");
     }
-    if ($config_value{'PEER_NODE_SSH_PASS_MODE'} eq "passfile" && $config_value{'PEER_NODE_SSH_PASS_FILE'} !~ /^\//){
-        printlog("ERROR", COMMON_MS0005, "PEER_NODE_SSH_PASS_FILE");
+    if ($config_value{'PEER_NODE_SSH_PASS_MODE'} eq "passfile"){
+        if (!defined($config_value{'PEER_NODE_SSH_PASS_FILE'})){ 
+          printlog("ERROR", COMMON_MS0004, "PEER_NODE_SSH_PASS_FILE");
+        }
+        if ($config_value{'PEER_NODE_SSH_PASS_FILE'} !~ /^\//){
+          printlog("ERROR", COMMON_MS0005, "PEER_NODE_SSH_PASS_FILE");
+        }
     }
-    if ($config_value{'BACKUP_NODE_SSH_PASS_MODE'} eq "passfile" && $config_value{'BACKUP_NODE_SSH_PASS_FILE'} !~ /^\//){
-        printlog("ERROR", COMMON_MS0005, "BACKUP_NODE_SSH_PASS_FILE");
+    if ($config_value{'BACKUP_NODE_SSH_PASS_MODE'} eq "passfile"){
+        if (!defined($config_value{'BACKUP_NODE_SSH_PASS_FILE'})){
+          printlog("ERROR", COMMON_MS0004, "BACKUP_NODE_SSH_PASS_FILE");
+        }
+        if ($config_value{'BACKUP_NODE_SSH_PASS_FILE'} !~ /^\//){
+          printlog("ERROR", COMMON_MS0005, "BACKUP_NODE_SSH_PASS_FILE");
+        }
     }
-
     # VIP_SLAVE が disable の場合、VIP-SLAVE_ResourceID の値を空にする
     if ($config_value{'VIP_SLAVE'} eq "disable"){
         $config_value{'VIP-SLAVE_ResourceID'} = "";
@@ -1243,11 +1252,15 @@ sub get_ssh_passwd {
         open (FILE, $ssh_pass_file) or printlog("ERROR", COMMON_MS0032, $ssh_pass_file);
         $passwd = <FILE>;
         close (FILE);
-
+        
+        if (!defined($passwd)){
+            printlog("ERROR", COMMON_MS0033, $ssh_pass_file);
+        }
+        
         chomp $passwd;
 
         if ( $passwd eq "" ){
-            printlog("ERROR", COMMON_MS0033);
+            printlog("ERROR", COMMON_MS0033, $ssh_pass_file);
         }
     }
 
